from math import pi
import numpy as np

cfg_plot = {
    "signal": "ttHTobb",
    "labels": {
        "ttHTobb": "$t\\bar{t}H\\rightarrow b\\bar{b}$",
        "TTToSemiLeptonic": "$t\\bar{t}$ semilep.",
        "TTTo2L2Nu" : "$t\\bar{t}$ dilepton",
        "SingleTop" : "Single t",
        "WJetsToLNu_HT" : "W+jets",
    },
    "variables": {
        "ElectronGood_pt_1": {'xlim' : (20,500), 'xticks' : np.concatenate(([20], np.arange(50, 550, 50))).tolist()},
        "ElectronGood_eta_1": {'xlim' : (-2.4,2.4), 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "ElectronGood_etaSC_1": {'xlim' : (-2.5,2.5), 'xticks' : np.round([-2.5, -2.0, -1.5660, -1.4442, -1.2, -1.0, -0.8, -0.6, -0.4, -0.2, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0, 1.2, 1.4442, 1.5660, 2.0, 2.5], 2).tolist()},
        "ElectronGood_phi_1": {'xlim' : (-pi,pi)},
        "MuonGood_pt_1": {'xlim' : (20,500), 'xticks' : np.concatenate(([20], np.arange(50, 550, 50))).tolist()},
        "MuonGood_eta_1": {'xlim' : (-2.4,2.4), 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "MuonGood_phi_1": {'xlim' : (-pi,pi)},
        "JetGood_pt_1": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,1}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_pt_2": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,2}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_pt_3": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,3}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_pt_4": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,4}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_pt_5": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,5}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_pt_6": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{j,6}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_1": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,1}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_2": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,2}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_3": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,3}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_4": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,4}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_5": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,5}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "bjet_pt_6": {'xlim' : (30,500), 'xlabel' : "$p_{T}^{bjet,6}$ [GeV]", 'xticks' : np.concatenate(([30], np.arange(50, 550, 50))).tolist()},
        "JetGood_eta_1": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,1}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_eta_2": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,2}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_eta_3": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,3}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_eta_4": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,4}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_eta_5": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,5}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_eta_6": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{j,6}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_1": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,1}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_2": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,2}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_3": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,3}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_4": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,4}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_5": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,5}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "bjet_eta_6": {'xlim' : (-2.4,2.4), 'xlabel' : "$\eta_{bjet,6}$", 'xticks' : np.round(np.arange(-2.4, 2.8, 0.4), 1).tolist()},
        "JetGood_phi_1": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,1}$"},
        "JetGood_phi_2": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,2}$"},
        "JetGood_phi_3": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,3}$"},
        "JetGood_phi_4": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,4}$"},
        "JetGood_phi_5": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,5}$"},
        "JetGood_phi_6": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{j,6}$"},
        "bjet_phi_1": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,1}$"},
        "bjet_phi_2": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,2}$"},
        "bjet_phi_3": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,3}$"},
        "bjet_phi_4": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,4}$"},
        "bjet_phi_5": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,5}$"},
        "bjet_phi_6": {'xlim' : (-pi,pi), 'xlabel' : "$\phi_{bjet,6}$"},
        "JetGood_btagDeepFlavB_1": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 1)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "JetGood_btagDeepFlavB_2": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 2)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "JetGood_btagDeepFlavB_3": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 3)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "JetGood_btagDeepFlavB_4": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 4)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "JetGood_btagDeepFlavB_5": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 5)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "JetGood_btagDeepFlavB_6": {'xlim' : (0,1), 'xlabel' : "AK4 DeepJet b-tag score (Jet 6)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_1": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 1)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_2": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 2)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_3": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 3)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_4": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 4)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_5": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 5)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "bjet_btagDeepFlavB_6": {'xlim' : (0,1), 'xlabel' : "bjet DeepJet b-tag score (Jet 6)", 'xticks' : np.round(np.arange(0.0, 1.1, 0.1), 1).tolist()},
        "MET_pt": {'xlim' : (20, 300), 'xticks' : np.concatenate(([20], np.arange(50, 350, 50))).tolist()},
        "MET_phi": {'xlim' : (-pi,pi)},
        "jets_Ht": {'xlim' : (50,2500), 'xticks' : np.concatenate(([50], np.arange(500, 3000, 500))).tolist()},
        "nBJets": {'xlim' : (1,8), 'scale' : "log", 'xticks' : list(range(1,9))},
        "nJets": {'xlim' : (4,14), 'scale' : "log", 'xticks' : list(range(4,15))},
        "nLepton": {'xlim' : (0,3), 'scale' : "log", 'xticks' : [0,1,2,3]},
    }
}
